==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkVolume.java <==
// java wrapper for vtkVolume object
//

package vtk;
import vtk.*;

public class vtkVolume extends vtkProp3D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetMapper_2(vtkAbstractVolumeMapper id0);
  public void SetMapper(vtkAbstractVolumeMapper id0)
    { SetMapper_2(id0); }

  private native long GetMapper_3();
  public vtkAbstractVolumeMapper GetMapper() {
    long temp = GetMapper_3();

    if (temp == 0) return null;
    return (vtkAbstractVolumeMapper)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetProperty_4(vtkVolumeProperty id0);
  public void SetProperty(vtkVolumeProperty id0)
    { SetProperty_4(id0); }

  private native long GetProperty_5();
  public vtkVolumeProperty GetProperty() {
    long temp = GetProperty_5();

    if (temp == 0) return null;
    return (vtkVolumeProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetVolumes_6(vtkPropCollection id0);
  public void GetVolumes(vtkPropCollection id0)
    { GetVolumes_6(id0); }

  private native void Update_7();
  public void Update()
    { Update_7(); }

  private native double[] GetBounds_8();
  public double[] GetBounds()
    { return GetBounds_8(); }

  private native void GetBounds_9(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_9(id0); }

  private native double GetMinXBound_10();
  public double GetMinXBound()
    { return GetMinXBound_10(); }

  private native double GetMaxXBound_11();
  public double GetMaxXBound()
    { return GetMaxXBound_11(); }

  private native double GetMinYBound_12();
  public double GetMinYBound()
    { return GetMinYBound_12(); }

  private native double GetMaxYBound_13();
  public double GetMaxYBound()
    { return GetMaxYBound_13(); }

  private native double GetMinZBound_14();
  public double GetMinZBound()
    { return GetMinZBound_14(); }

  private native double GetMaxZBound_15();
  public double GetMaxZBound()
    { return GetMaxZBound_15(); }

  private native int GetMTime_16();
  public int GetMTime()
    { return GetMTime_16(); }

  private native int GetRedrawMTime_17();
  public int GetRedrawMTime()
    { return GetRedrawMTime_17(); }

  private native void ShallowCopy_18(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_18(id0); }

  private native int RenderVolumetricGeometry_19(vtkViewport id0);
  public int RenderVolumetricGeometry(vtkViewport id0)
    { return RenderVolumetricGeometry_19(id0); }

  private native void ReleaseGraphicsResources_20(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_20(id0); }

  private native double GetGradientOpacityConstant_21(int id0);
  public double GetGradientOpacityConstant(int id0)
    { return GetGradientOpacityConstant_21(id0); }

  private native double GetGradientOpacityConstant_22();
  public double GetGradientOpacityConstant()
    { return GetGradientOpacityConstant_22(); }

  private native double GetArraySize_23();
  public double GetArraySize()
    { return GetArraySize_23(); }

  private native void UpdateTransferFunctions_24(vtkRenderer id0);
  public void UpdateTransferFunctions(vtkRenderer id0)
    { UpdateTransferFunctions_24(id0); }

  private native void UpdateScalarOpacityforSampleSize_25(vtkRenderer id0,double id1);
  public void UpdateScalarOpacityforSampleSize(vtkRenderer id0,double id1)
    { UpdateScalarOpacityforSampleSize_25(id0,id1); }

  private native boolean GetSupportsSelection_26();
  public boolean GetSupportsSelection()
    { return GetSupportsSelection_26(); }

  public vtkVolume() { super(); }

  public vtkVolume(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-3-armv7h.pkg.tar.xz: vtk/vtkVolume.java <==
// java wrapper for vtkVolume object
//

package vtk;
import vtk.*;

public class vtkVolume extends vtkProp3D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetMapper_2(vtkAbstractVolumeMapper id0);
  public void SetMapper(vtkAbstractVolumeMapper id0)
    { SetMapper_2(id0); }

  private native long GetMapper_3();
  public vtkAbstractVolumeMapper GetMapper() {
    long temp = GetMapper_3();

    if (temp == 0) return null;
    return (vtkAbstractVolumeMapper)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetProperty_4(vtkVolumeProperty id0);
  public void SetProperty(vtkVolumeProperty id0)
    { SetProperty_4(id0); }

  private native long GetProperty_5();
  public vtkVolumeProperty GetProperty() {
    long temp = GetProperty_5();

    if (temp == 0) return null;
    return (vtkVolumeProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetVolumes_6(vtkPropCollection id0);
  public void GetVolumes(vtkPropCollection id0)
    { GetVolumes_6(id0); }

  private native void Update_7();
  public void Update()
    { Update_7(); }

  private native double[] GetBounds_8();
  public double[] GetBounds()
    { return GetBounds_8(); }

  private native void GetBounds_9(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_9(id0); }

  private native double GetMinXBound_10();
  public double GetMinXBound()
    { return GetMinXBound_10(); }

  private native double GetMaxXBound_11();
  public double GetMaxXBound()
    { return GetMaxXBound_11(); }

  private native double GetMinYBound_12();
  public double GetMinYBound()
    { return GetMinYBound_12(); }

  private native double GetMaxYBound_13();
  public double GetMaxYBound()
    { return GetMaxYBound_13(); }

  private native double GetMinZBound_14();
  public double GetMinZBound()
    { return GetMinZBound_14(); }

  private native double GetMaxZBound_15();
  public double GetMaxZBound()
    { return GetMaxZBound_15(); }

  private native int GetMTime_16();
  public int GetMTime()
    { return GetMTime_16(); }

  private native int GetRedrawMTime_17();
  public int GetRedrawMTime()
    { return GetRedrawMTime_17(); }

  private native void ShallowCopy_18(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_18(id0); }

  private native int RenderVolumetricGeometry_19(vtkViewport id0);
  public int RenderVolumetricGeometry(vtkViewport id0)
    { return RenderVolumetricGeometry_19(id0); }

  private native void ReleaseGraphicsResources_20(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_20(id0); }

  private native double GetGradientOpacityConstant_21(int id0);
  public double GetGradientOpacityConstant(int id0)
    { return GetGradientOpacityConstant_21(id0); }

  private native double GetGradientOpacityConstant_22();
  public double GetGradientOpacityConstant()
    { return GetGradientOpacityConstant_22(); }

  private native double GetArraySize_23();
  public double GetArraySize()
    { return GetArraySize_23(); }

  private native void UpdateTransferFunctions_24(vtkRenderer id0);
  public void UpdateTransferFunctions(vtkRenderer id0)
    { UpdateTransferFunctions_24(id0); }

  private native void UpdateScalarOpacityforSampleSize_25(vtkRenderer id0,double id1);
  public void UpdateScalarOpacityforSampleSize(vtkRenderer id0,double id1)
    { UpdateScalarOpacityforSampleSize_25(id0,id1); }

  private native boolean GetSupportsSelection_26();
  public boolean GetSupportsSelection()
    { return GetSupportsSelection_26(); }

  public vtkVolume() { super(); }

  public vtkVolume(long id) { super(id); }
  public native long   VTKInit();

}
